@@ -176,7 +176,7 @@ def create_tables():
                                        FROM weapon_types) weap_type
 
                             USING (name)
-                            WHERE type like ('%Missile%') and NAME IS NOT NULL) weap
+                            WHERE type = 'Weapon+Missile' and NAME IS NOT NULL) weap
                 USING (weapon)
                 WHERE killer IS NOT NULL AND
                     target IS NOT NULL AND weapon IS NOT NULL
